#! /usr/bin/env python3
# -*- coding: utf-8 -*-
""" Construct boomerang fraction sequences for a list of input values."""


from fractions import Fraction


ADDITION_OPERATION = "\u2192"
INVERSION_OPERATION = "\u21bb"
OUTPUT_TEMPLATE = "{}/{}\n{}\n"
SEQUENCE_DELIMITER = " "


def boomerang(fraction):
    """Construct and return a boomerang fraction sequence.
    
    Arguments:
        fraction -- Additive term in boomerang fraction sequence.
    Return value:
        Sequence of interleaved values and operations.
    """
    value = Fraction(1)
    sequence = [value]
    while True:
        value -= fraction
        sequence = [value, ADDITION_OPERATION] + sequence
        if value == 1:
            break
        if value <= fraction:  # Subtraction not possible; invert. 
            value = 1 / value
            sequence = [value, INVERSION_OPERATION] + sequence
    return sequence


if __name__ == '__main__':
    for m, n in [(1, 2), (2, 3), (1, 4), (4, 5), (2, 5)]:
        sequence = boomerang(Fraction(m, n))
        print(OUTPUT_TEMPLATE.format(m, n, 
            SEQUENCE_DELIMITER.join(str(s) for s in sequence)))
